NS_API

Struct NS_API 

pub struct NS_API { /* private fields */ }

Methods from Deref<Target = StaticIRI>

pub fn dup(&self) -> Uri<&'a str>

Duplicates this Uri<&str>.

pub fn to_owned(&self) -> Uri<String>

Creates a new Uri<String> by cloning the contents of this Uri<&str>.

pub fn as_str(&'i self) -> &'o str

Returns the URI reference as a string slice.

pub fn scheme(&'i self) -> Option<&'o Scheme>

Returns the scheme component.

pub fn authority(&self) -> Option<&Authority<T>>

Returns the authority component.

pub fn path(&'i self) -> &'o Path

Returns the path component.

Panics

Panics if the path component is already taken.

pub fn query(&'i self) -> Option<&'o EStr>

Returns the query component.

pub fn fragment(&'i self) -> Option<&'o EStr>

Returns the fragment component.

pub fn is_relative(&self) -> bool

Returns true if the URI reference is relative, i.e., without a scheme.

Note that this method is not the opposite of is_absolute.

Examples
use fluent_uri::Uri;

let uri = Uri::parse("/path/to/file")?;
assert!(uri.is_relative());
let uri = Uri::parse("http://example.com/")?;
assert!(!uri.is_relative());
pub fn is_absolute(&self) -> bool

Returns true if the URI reference is absolute, i.e., with a scheme and without a fragment.

Note that this method is not the opposite of is_relative.

Examples
use fluent_uri::Uri;

let uri = Uri::parse("http://example.com/")?;
assert!(uri.is_absolute());
let uri = Uri::parse("http://example.com/#title1")?;
assert!(!uri.is_absolute());
let uri = Uri::parse("/path/to/file")?;
assert!(!uri.is_absolute());
pub fn borrow(&self) -> &Uri<&str>

Borrows this Uri<String> as a reference to Uri<&str>.